@@ -8,10 +8,13 @@
 pub mod core_collection;
 
 pub mod arithmetic;
+pub mod audio;
 pub mod cast;
 pub mod conversion;
 pub mod generation;
+pub mod flow;
 pub mod fs;
 pub mod net;
+pub mod text;
 
 pub mod prelude;
