@@ -4,15 +4,12 @@ use std::collections::HashMap;
 use super::*;
 use super::super::error::LogicError;
 use super::super::designer::SequenceDesigner;
-use super::super::designer::TreatmentDesigner;
 use super::super::designer::{ConnectionDesigner, ConnectionIODesigner};
 use super::super::descriptor::parameterized::Parameterized;
 use super::super::descriptor::TreatmentDescriptor;
 use super::super::descriptor::IdentifiedDescriptor;
 use super::super::super::executive::environment::{GenesisEnvironment, ContextualEnvironment};
 use super::super::super::executive::model::Model;
-use super::super::super::executive::future::*;
-use super::super::super::executive::transmitter::Transmitter;
 use super::super::designer::value::Value;
 
 #[derive(Debug)]
@@ -83,8 +80,18 @@ impl Builder for SequenceBuilder {
         let mut builds_writer = self.builds.write().unwrap();
         let idx = builds_writer.len() as BuildId;
 
+        let rc_designer = self.designer.read().unwrap();
+
+        // Assigning missing default values
+        let mut missing_default = HashMap::new();
+        for (name, parameter) in rc_designer.descriptor().parameters().iter().filter(|(_, p)| p.default().is_some()) {
+            if !environment.variables().contains_key(name) {
+                missing_default.insert(name, parameter.default().as_ref().unwrap().clone());
+            }
+        }
+
         // Instanciate models
-        for (instanciation_name, model_instanciation) in self.designer.read().unwrap().model_instanciations() {
+        for (instanciation_name, model_instanciation) in rc_designer.model_instanciations() {
 
             let mut remastered_environment = environment.base();
 
@@ -95,7 +102,12 @@ impl Builder for SequenceBuilder {
                 let data = match borrowed_param.value().as_ref().unwrap() {
                     Value::Raw(data) => data,
                     Value::Variable(name) => {
-                        environment.get_variable(&name).unwrap()
+                        if let Some(data) = environment.get_variable(&name) {
+                            data
+                        }
+                        else {
+                            missing_default.get(name).unwrap()
+                        }
                     },
                     // Not possible in model instanciation to use context, should have been catched by designer, aborting
                     _ => panic!("Impossible data recoverage")
@@ -105,7 +117,7 @@ impl Builder for SequenceBuilder {
             }
 
             let instanciation_result = model_instanciation.read().unwrap().descriptor().builder().static_build(
-                Some(Arc::clone(self.designer.read().unwrap().descriptor()) as Arc<dyn TreatmentDescriptor>),
+                Some(Arc::clone(rc_designer.descriptor()) as Arc<dyn TreatmentDescriptor>),
                 Some(idx),
                 instanciation_name.to_string(),
                 &remastered_environment
@@ -121,7 +133,7 @@ impl Builder for SequenceBuilder {
         }
 
         // Make the internal treatments being built
-        for (treatment_name, treatment) in self.designer.read().unwrap().treatments() {
+        for (treatment_name, treatment) in rc_designer.treatments() {
 
             let borrowed_treatment = treatment.read().unwrap();
             let mut remastered_environment = environment.base();
@@ -164,7 +176,12 @@ impl Builder for SequenceBuilder {
                 let data = match borrowed_param.value().as_ref().unwrap() {
                     Value::Raw(data) => data,
                     Value::Variable(name) => {
-                        environment.get_variable(&name).unwrap()
+                        if let Some(data) = environment.get_variable(&name) {
+                            data
+                        }
+                        else {
+                            missing_default.get(name).unwrap()
+                        }
                     },
                     // We should have a value there, should have been catched by designer, aborting
                     _ => panic!("Impossible data recoverage")
@@ -174,7 +191,7 @@ impl Builder for SequenceBuilder {
             }
 
             let build_result = borrowed_treatment.descriptor().builder().static_build(
-                Some(Arc::clone(self.designer.read().unwrap().descriptor()) as Arc<dyn TreatmentDescriptor>),
+                Some(Arc::clone(rc_designer.descriptor()) as Arc<dyn TreatmentDescriptor>),
                 Some(idx),
                 treatment_name.to_string(),
                 &remastered_environment
@@ -189,7 +206,7 @@ impl Builder for SequenceBuilder {
         }
 
         // Order the internal treatments
-        for connection in self.designer.read().unwrap().connections() {
+        for connection in rc_designer.connections() {
 
             let borrowed_connection = connection.read().unwrap();
 
@@ -342,7 +359,13 @@ impl Builder for SequenceBuilder {
                 let data = match borrowed_param.value().as_ref().unwrap() {
                     Value::Raw(data) => data,
                     Value::Variable(name) => {
-                        environment.get_variable(&name).unwrap()
+                        // TODO change once distinction between const & var is fully implemented
+                        if let Some(data) = environment.get_variable(&name) {
+                            data
+                        }
+                        else {
+                            build_sample.genesis_environment.get_variable(&name).unwrap()
+                        }
                     },
                     Value::Context((context, name)) => {
                         environment.get_context(context).unwrap().get_value(name).unwrap()
@@ -470,7 +493,13 @@ impl Builder for SequenceBuilder {
                     let data = match borrowed_param.value().as_ref().unwrap() {
                         Value::Raw(data) => data,
                         Value::Variable(name) => {
-                            environment.get_variable(&name).unwrap()
+                            // TODO change once distinction between const & var is fully implemented
+                            if let Some(data) = environment.get_variable(&name) {
+                                data
+                            }
+                            else {
+                                build_sample.genesis_environment.get_variable(&name).unwrap()
+                            }
                         },
                         Value::Context((context, name)) => {
                             environment.get_context(context).unwrap().get_value(name).unwrap()
@@ -556,7 +585,7 @@ impl Builder for SequenceBuilder {
             identifier: self.designer.read().unwrap().descriptor().identifier().clone(),
             build_id: build,
         };
-        if let Some(existing_check_step) = previous_steps.iter().find(|&cs| cs == &check_step) {
+        if let Some(_existing_check_step) = previous_steps.iter().find(|&cs| cs == &check_step) {
             
             errors.push(LogicError::already_included_build_step());
         }
@@ -620,7 +649,7 @@ impl Builder for SequenceBuilder {
 
     fn check_give_next(&self, within_build: BuildId, for_label: String, environment: CheckEnvironment, previous_steps: Vec<CheckStep>) -> Option<CheckBuildResult> {
 
-        let mut errors = Vec::new();
+        let errors = Vec::new();
         // (Check if environment is satisfied)
         //  ↑ actually not because next treatment may not require it -checking evolution to do-
 
@@ -641,16 +670,17 @@ impl Builder for SequenceBuilder {
             let asking_treatment_tuple = (for_label.to_string(), *build_sample.treatment_build_ids.get(&for_label).unwrap());
 
             // Get the treatments connected right after the given label in the reffered build
-            let next_treatments = build_sample.next_treatments_build_ids.get(&asking_treatment_tuple).unwrap();
-            for (next_treatment_name, next_treatment_id) in next_treatments {
+            if let Some(next_treatments) = build_sample.next_treatments_build_ids.get(&asking_treatment_tuple) {
+                for (next_treatment_name, next_treatment_id) in next_treatments {
 
-                let rc_designer = self.designer.read().unwrap();
-                let borrowed_next_treatment = rc_designer.treatments().get(next_treatment_name).unwrap().read().unwrap();
-                let next_treatment_builder = borrowed_next_treatment.descriptor().builder();
+                    let rc_designer = self.designer.read().unwrap();
+                    let borrowed_next_treatment = rc_designer.treatments().get(next_treatment_name).unwrap().read().unwrap();
+                    let next_treatment_builder = borrowed_next_treatment.descriptor().builder();
 
-                let check_result = next_treatment_builder.check_dynamic_build(*next_treatment_id, environment.clone(), previous_steps.clone()).unwrap();
+                    let check_result = next_treatment_builder.check_dynamic_build(*next_treatment_id, environment.clone(), previous_steps.clone()).unwrap();
 
-                treatment_build_results.insert(next_treatment_name.to_string(), check_result);
+                    treatment_build_results.insert(next_treatment_name.to_string(), check_result);
+                }
             }
 
             if let Some(next_connections) = build_sample.next_connections.get(&asking_treatment_tuple) {
