@@ -1,12 +1,22 @@
 
 use std::fmt::*;
 use super::datatype::DataType;
+use super::variability::Variability;
 use crate::executive::value::Value;
 
 macro_rules! parameter {
     ($name:expr,$data_structure:ident,$data_type:ident,$default:expr) => {
         crate::logic::descriptor::parameter::Parameter::new(
             $name,
+            crate::logic::descriptor::variability::Variability::Const,
+            datatype!($data_structure,$data_type),
+            $default,
+        )
+    };
+    ($name:expr,$variability:ident,$data_structure:ident,$data_type:ident,$default:expr) => {
+        crate::logic::descriptor::parameter::Parameter::new(
+            $name,
+            crate::logic::descriptor::variability::Variability::$variability,
             datatype!($data_structure,$data_type),
             $default,
         )
@@ -17,14 +27,16 @@ pub(crate) use parameter;
 #[derive(Clone, PartialEq, Debug)]
 pub struct Parameter {
     name: String,
+    variability: Variability,
     datatype: DataType,
     default: Option<Value>,
 }
 
 impl Parameter {
-    pub fn new(name: &str, datatype: DataType, default: Option<Value>) -> Self {
+    pub fn new(name: &str, variability: Variability, datatype: DataType, default: Option<Value>) -> Self {
         Self {
             name: name.to_string(),
+            variability,
             datatype,
             default,
         }
@@ -34,6 +46,10 @@ impl Parameter {
         &self.name
     }
 
+    pub fn variability(&self) -> &Variability {
+        &self.variability
+    }
+
     pub fn datatype(&self) -> &DataType {
         &self.datatype
     }
@@ -48,10 +64,10 @@ impl Display for Parameter {
     fn fmt(&self, f: &mut Formatter<'_>) -> Result {
 
         if let Some(default) = &self.default {
-            write!(f, "_{}_: `{}` (default `{}`)", self.name, self.datatype, default)
+            write!(f, "{} _{}_: `{}` (default `{}`)", self.variability, self.name, self.datatype, default)
         }
         else {
-            write!(f, "_{}_: `{}`", self.name, self.datatype)
+            write!(f, "{} _{}_: `{}`", self.variability, self.name, self.datatype)
         }
         
     }
