@@ -63,7 +63,7 @@ impl Sequence {
     /// # use melodium::script::error::ScriptError;
     /// # use melodium::script::text::script::Script as TextScript;
     /// # use melodium::script::semantic::script::Script;
-    /// let address = "examples/semantic/simple_build.mel";
+    /// let address = "melodium-tests/semantic/simple_build.mel";
     /// let mut raw_text = String::new();
     /// # let mut file = File::open(address).unwrap();
     /// # file.read_to_string(&mut raw_text);
@@ -179,7 +179,7 @@ impl Sequence {
     /// # use melodium::script::error::ScriptError;
     /// # use melodium::script::text::script::Script as TextScript;
     /// # use melodium::script::semantic::script::Script;
-    /// let address = "examples/semantic/simple_build.mel";
+    /// let address = "melodium-tests/semantic/simple_build.mel";
     /// let mut raw_text = String::new();
     /// # let mut file = File::open(address).unwrap();
     /// # file.read_to_string(&mut raw_text);
@@ -210,7 +210,7 @@ impl Sequence {
     /// # use melodium::script::error::ScriptError;
     /// # use melodium::script::text::script::Script as TextScript;
     /// # use melodium::script::semantic::script::Script;
-    /// let address = "examples/semantic/simple_build.mel";
+    /// let address = "melodium-tests/semantic/simple_build.mel";
     /// let mut raw_text = String::new();
     /// # let mut file = File::open(address).unwrap();
     /// # file.read_to_string(&mut raw_text);
@@ -241,7 +241,7 @@ impl Sequence {
     /// # use melodium::script::error::ScriptError;
     /// # use melodium::script::text::script::Script as TextScript;
     /// # use melodium::script::semantic::script::Script;
-    /// let address = "examples/semantic/simple_build.mel";
+    /// let address = "melodium-tests/semantic/simple_build.mel";
     /// let mut raw_text = String::new();
     /// # let mut file = File::open(address).unwrap();
     /// # file.read_to_string(&mut raw_text);
@@ -272,7 +272,7 @@ impl Sequence {
     /// # use melodium::script::error::ScriptError;
     /// # use melodium::script::text::script::Script as TextScript;
     /// # use melodium::script::semantic::script::Script;
-    /// let address = "examples/semantic/simple_build.mel";
+    /// let address = "melodium-tests/semantic/simple_build.mel";
     /// let mut raw_text = String::new();
     /// # let mut file = File::open(address).unwrap();
     /// # file.read_to_string(&mut raw_text);
@@ -303,7 +303,7 @@ impl Sequence {
     /// # use melodium::script::error::ScriptError;
     /// # use melodium::script::text::script::Script as TextScript;
     /// # use melodium::script::semantic::script::Script;
-    /// let address = "examples/semantic/simple_build.mel";
+    /// let address = "melodium-tests/semantic/simple_build.mel";
     /// let mut raw_text = String::new();
     /// # let mut file = File::open(address).unwrap();
     /// # file.read_to_string(&mut raw_text);
@@ -334,7 +334,7 @@ impl Sequence {
     /// # use melodium::script::error::ScriptError;
     /// # use melodium::script::text::script::Script as TextScript;
     /// # use melodium::script::semantic::script::Script;
-    /// let address = "examples/semantic/simple_build.mel";
+    /// let address = "melodium-tests/semantic/simple_build.mel";
     /// let mut raw_text = String::new();
     /// # let mut file = File::open(address).unwrap();
     /// # file.read_to_string(&mut raw_text);
@@ -373,6 +373,9 @@ impl Sequence {
                 DeclaredModelRefersTo::Use(u) => {
                     u.reference.as_ref().unwrap().upgrade().unwrap().read().unwrap().identifier.as_ref().unwrap().clone()
                 },
+                DeclaredModelRefersTo::Model(m) => {
+                    m.reference.as_ref().unwrap().upgrade().unwrap().read().unwrap().identifier.as_ref().unwrap().clone()
+                },
                 _ => panic!("{:?}", &borrowed_model.refers)
             };
 
@@ -422,10 +425,7 @@ impl Sequence {
             descriptor.add_requirement(requirement_descriptor);
         }
 
-        let rc_descriptor = Arc::new(descriptor);
-        rc_descriptor.set_autoref(&rc_descriptor);
-
-        collection.treatments.insert(&(rc_descriptor as Arc<dyn TreatmentDescriptor>));
+        collection.treatments.insert(&(descriptor.commit() as Arc<dyn TreatmentDescriptor>));
 
         Ok(())
 
@@ -455,10 +455,10 @@ impl Sequence {
 
             let treatment = rc_treatment.read().unwrap();
 
-            let treatment_designer = rc_designer.write().unwrap().add_treatment(
+            let treatment_designer = wrap_logic_error!(rc_designer.write().unwrap().add_treatment(
                     treatment.type_identifier.as_ref().unwrap(),
                     &treatment.name
-                ).unwrap();
+                ), treatment.text.name.position);
 
             treatment.make_design(&treatment_designer)?;
         }
@@ -525,7 +525,7 @@ impl DeclarativeElement for Sequence {
     /// # use melodium::script::text::script::Script as TextScript;
     /// # use melodium::script::semantic::script::Script;
     /// # use melodium::script::semantic::declarative_element::DeclarativeElement;
-    /// let address = "examples/semantic/simple_build.mel";
+    /// let address = "melodium-tests/semantic/simple_build.mel";
     /// let mut raw_text = String::new();
     /// # let mut file = File::open(address).unwrap();
     /// # file.read_to_string(&mut raw_text);
